# Welcome to NeuralActivityCubic


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

NeuralActivityCubic (NA³) is an open-source calcium image analysis tool
published in 2018 by J. Prada and colleagues[^1], who describe it as
following in their [Author
Summary](https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1006054#abstract1):

> Calcium imaging has become a standard tool to investigate local,
> spontaneous, or cell-autonomous calcium signals in neurons. Some of
> these calcium signals are fast and ‘small’, thus making it difficult
> to identify real signaling events due to an unavoidable signal noise.
> Therefore, it is difficult to assess the spatiotemporal activity
> footprint of individual neurons or a neuronal network. We developed
> this open source tool to automatically extract, count, and localize
> calcium signals from the whole x,y-t image series. As demonstrated
> here, the tool is useful for an unbiased comparison of activity states
> of neurons, helps to assess local calcium transients, and even
> visualizes local homeostatic calcium activity. The tool is powerful
> enough to visualize signal-close-to-noise calcium activity.

Since its publication in 2018, updates to several software packages on
which [the original implementation of
NA3](https://github.com/jpits30/NeuronActivityTool) depends have
rendered this version of NA³ virtually un-installable and, thus,
effectively inaccessible for its target user audience - the
Neuroscientific Community. Given the continued interest in NA³, however,
this was not acceptable. Thus, we formed a collaboration between the
original developers of NA³ and research software engineering experts
from the not-for-profit organization [Indoc Research
Europe](https://www.indocresearch.eu/) to revamp NA³, with the goal of
making it easily accessible to the Neuroscientific Community once again.
While on it, we also enhanced NA³´s performance, it´s scope of features,
and it´s maintainability to ensure NA³ remains accessible moving
forward. Today, we´re happy to present to you this revamped version of
NA³ - we hope you´ll like it!

**Note:** We´re still putting a few finishing touches on this new
implementation of NA³, so please be aware that this version remains
under active development and should not yet be considered as a stable
release. We´re currently also working on a paper describing our work in
more details, so make sure you stay tuned and regularly check these docs
for updates!

## Usage

### Installation

If you´re comfortable working with virtual Python environments and
installing packages via command line interfaces, please follow one of
the subsequent options to install NA³. If you´d prefer a full
step-by-step guide instead, we also got you covered: please find our
detailed installation guide
[here](https://indoc-research.github.io/NeuralActivityCubic/installation.html).

Install latest from
[GitHub](https://github.com/Indoc-Research/NeuralActivityCubic):

``` sh
$ pip install git+https://github.com/Indoc-Research/neuralactivitycubic.git
```

or from [pypi](https://pypi.org/project/neuralactivitycubic/)

``` sh
$ pip install neuralactivitycubic
```

### Documentation

Documentation for NA³ can be found
[here](https://indoc-research.github.io/NeuralActivityCubic/).

## How to use - quick start:

After installing `neuralactivitycubic`, open a Jupyter Notebook and
execute the following code to launch the GUI of NA³:

``` python
import neuralactivitycubic as na3

na3.open_gui()
```

![GUI of NA³.](./media/welcome_to_na3.png)

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install NeuralActivityCubic in Development mode

``` sh
# make sure NeuralActivityCubic package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to NeuralActivityCubic
$ nbdev_prepare
```

[^1]: Prada J, Sasi M, Martin C, Jablonka S, Dandekar T, Blum R (2018)
    An open source tool for automatic spatiotemporal assessment of
    calcium transients and local ‘signal-close-to-noise’ activity in
    calcium imaging data. PLoS computational biology 14(3): e1006054.
    https://doi.org/10.1371/journal.pcbi.1006054
